require "base64"
require "resultable"
require "ostruct"
require "yaml"
require 'rest-client'

module ForteRuby
  module API
    class Base
      include Resultable

      attr_accessor :request_data

      def initialize(params = {})
        set_attributes(params)
        self.request_data ||= RequestData.new
      end
      
      private

      def send_request(url, method, params = nil)
        self.result = Result.new

        unless request_data.config
          result.error = 'Provide configs in forte_ruby.yml file'
          return result
        end

        params = params ? JSON.generate(params) : nil
        begin
          response = RestClient.send(method, url, *[params, request_data.headers].compact)
          result.successful!
          if block_given? 
            yield(response)
          else
            result.response = JSON.parse(response)
          end
        rescue RestClient::Exception => e
          result.response = JSON.parse(e.response)['response']['response_desc']
        end

        result
      end

      def set_attributes(attributes)
        attributes.each do |key, value|
          self.send("#{key}=", value) if self.respond_to?(key)
        end
      end
    end
  end
end
