module ForteRuby
  module API
    class RequestData
      attr_accessor :config

      def initialize
        self.config = parse_config_file
      end

      def base_url
        "#{config.endpoint}/accounts/#{account_id}/locations/#{location_id}"
      end

      def headers
        {
          'X-Forte-Auth-Account-Id' => account_id,
          'Authorization' => "Basic #{signature}",
          'Accept' => 'application/json',
          'Content-Type' => 'json'
        }
      end

      private

      def account_id
        "act_#{config.account_id}"
      end

      def location_id
        "loc_#{config.location_id}"
      end

      def parse_config_file
        file = Rails.root.join("config").join("forte_ruby.yml")
        data = YAML.load(ERB.new(IO.read(file)).result)[Rails.env] rescue nil
        data ? OpenStruct.new(data) : data
      end

      def signature
        credentials = "#{config.api_login_id}:#{config.secure_transaction_key}"
        Base64.encode64(credentials).gsub("\n", "")
      end
    end
  end
end
